class NowPlaying extends HTMLElement {
  static tagName = "now-playing";

  static register(tagName = this.tagName, registry = globalThis.customElements) {
    registry.define(tagName, this);
  }

  async connectedCallback() {
    this.contentElement = this.querySelector(".content");
    if (!this.contentElement) return;

    const cache = localStorage.getItem("now-playing-cache");
    if (cache) this.updateHTML(JSON.parse(cache));

    await this.fetchAndUpdate();
  }

  async fetchAndUpdate() {
    try {
      const data = await this.fetchData();
      const newHTML = data?.content;

      if (newHTML && newHTML !== this.contentElement.innerHTML) {
        this.updateHTML(newHTML);
        localStorage.setItem("now-playing-cache", JSON.stringify(newHTML));
      }
    } catch {}
  }

  updateHTML(value) {
    this.contentElement.innerHTML = value;
  }

  async fetchData() {
    return fetch(`/api/playing.php?nocache=${Date.now()}`)
      .then(response => response.json())
      .catch(() => ({}));
  }
}

NowPlaying.register();
