class SelectPagination extends HTMLElement {
  static register(tagName = 'select-pagination') {
    if ("customElements" in window) customElements.define(tagName, this)
  }

  static get observedAttributes() {
    return ['data-base-index']
  }

  get baseIndex() {
    return parseInt(this.getAttribute('data-base-index') || '0', 10)
  }

  connectedCallback() {
    if (this.shadowRoot) return

    this.attachShadow({ mode: 'open' }).appendChild(document.createElement('slot'))

    const uriSegments = window.location.pathname.split('/').filter(Boolean)
    let pageNumber = this.extractPageNumber(uriSegments)
    if (pageNumber === null) pageNumber = this.baseIndex

    this.control = this.querySelector('select')
    this.control.value = pageNumber.toString()
    this.control.addEventListener('change', (event) => {
      pageNumber = parseInt(event.target.value)
      const updatedUrlSegments = this.updateUrlSegments(uriSegments, pageNumber)
      window.location.href = `${window.location.origin}/${updatedUrlSegments.join('/')}`
    })
  }

  extractPageNumber(segments) {
    const lastSegment = segments[segments.length - 1]
    return !isNaN(lastSegment) ? parseInt(lastSegment) : null
  }

  updateUrlSegments(segments, pageNumber) {
    const lastIsPage = !isNaN(segments[segments.length - 1])

    if (lastIsPage) {
      segments[segments.length - 1] = pageNumber.toString()
    } else {
      segments.push(pageNumber.toString())
    }

    if (pageNumber === this.baseIndex) segments.pop()

    return segments
  }
}

SelectPagination.register()
