import EleventyFetch from "@11ty/eleventy-fetch";

const { POSTGREST_URL, POSTGREST_API_KEY } = process.env;

const fetchAllRobots = async () => {
  try {
    const data = await EleventyFetch(
      `${POSTGREST_URL}/optimized_robots?select=path,user_agents`,
      {
        duration: "1h",
        type: "json",
        fetchOptions: {
          method: "GET",
          headers: {
            "Content-Type": "application/json",
            Authorization: `Bearer ${POSTGREST_API_KEY}`,
          },
        },
      },
    );

    const sortedData = data.sort((a, b) => {
      const aHasWildcard = a.user_agents.includes("*") ? 0 : 1;
      const bHasWildcard = b.user_agents.includes("*") ? 0 : 1;
      return aHasWildcard - bHasWildcard || a.path.localeCompare(b.path);
    });

    return sortedData;
  } catch (error) {
    console.error("Error fetching robot data:", error);
    return [];
  }
};

export default async function () {
  return await fetchAllRobots();
}
