import EleventyFetch from "@11ty/eleventy-fetch";

const { POSTGREST_URL, POSTGREST_API_KEY } = process.env;

const fetchAllShows = async () => {
  try {
    return await EleventyFetch(`${POSTGREST_URL}/optimized_shows?select=*`, {
      duration: "1h",
      type: "json",
      fetchOptions: {
        method: "GET",
        headers: {
          "Content-Type": "application/json",
          Authorization: `Bearer ${POSTGREST_API_KEY}`,
        },
      },
    });
  } catch (error) {
    console.error("Error fetching shows:", error);
    return [];
  }
};

export default async function () {
  try {
    const shows = await fetchAllShows();

    const watchedShows = shows.filter(
      (show) => show.last_watched_at !== null,
    );

    const episodes = watchedShows.map((show) => ({
      title: show.episode.title,
      year: show.year,
      formatted_episode: show.episode.formatted_episode,
      url: show.episode.url,
      image: show.episode.image,
      backdrop: show.episode.backdrop,
      last_watched_at: show.episode.last_watched_at,
      grid: show.grid,
    }));

    return {
      shows,
      recentlyWatched: episodes.slice(0, 125),
      favorites: shows
        .filter((show) => show.favorite)
        .sort((a, b) => a.title.localeCompare(b.title)),
    };
  } catch (error) {
    console.error("Error fetching and processing shows data:", error);

    return {
      shows: [],
      recentlyWatched: [],
      favorites: [],
    };
  }
}
